import argparse
import pandas as pd
from raiss.filter_format_output import filter_output
from raiss.imputation_launcher import ImputationLauncher
from raiss.pipes import save_chromosome_imputation


def launch_chromosome_imputation(args):
    """
    Function allow the calling of the ImputationLauncher.chromosome_imputation
    method from an entry point

    Args:
        args (dict): Argument parsed from the command line see the
        __main__.add_chromosome_imputation_argument(parser) function.
    """
    save_chromosome_imputation(args.gwas, args.chrom, args.window_size,
                             args.buffer_size, args.l2_regularization, args.eigen_threshold,
                             args.zscore_folder, args.ref_folder, args.ld_folder, args.output_folder,
                             args.R2_threshold, ref_panel_suffix=args.ref_panel_suffix,
                             ld_type=args.ld_type, minimum_ld=args.minimum_ld)

def add_chromosome_imputation_argument():

    parser = argparse.ArgumentParser()
    parser.add_argument('--chrom', required=True, help= "chromosome to impute to the chr\d+ format")
    parser.add_argument('--gwas', required=True, help= "GWAS to impute to the consortia_trait format")

    parser.add_argument('--ref-folder', required=True, help= "reference panel location (used to determine which snp to impute)")
    parser.add_argument('--ld-folder', required=True, help= "Location  LD correlation matrices")
    parser.add_argument('--zscore-folder', required=True, help= "Location of the zscore files of the gwases to impute")
    parser.add_argument('--output-folder', required=True, help= "Location of the impute zscore files")

    parser.add_argument('--window-size', help= "Size of the non overlapping window", default = 500000)
    parser.add_argument('--buffer-size', help= "Size of the buffer around the imputation window", default = 125000)
    parser.add_argument('--l2-regularization', help= "Size of the small value added to the diagonal of the covariance matrix before inversion", default = 0.1)
    parser.add_argument('--eigen-threshold', help= "threshold under which eigen vectors are removed for the computation of the pseudo inverse", default = 0.1)

    parser.add_argument('--R2-threshold', help= "R square (imputation quality) threshold bellow which SNPs are filtered from the output", default = 0.6)
    parser.add_argument("--ld-type", help= "Ld can be supplied as plink command --ld-snp-list output files (see raiss.ld_matrix.launch_plink_ld to compute these data using plink) or as a couple of a scipy sparse matrix (.npz )and an .csv containing SNPs index", default="plink")
    parser.add_argument('--ref-panel-suffix', help= "end of the suffix for the reference panel files", default = ".bim")
    parser.add_argument('--minimum-ld', help = "this parameter ensure that their is enough typed SNPs around the imputed to perform a high accuracy imputation", default = 4)

    parser.set_defaults(func=launch_chromosome_imputation)
    return(parser)

def main():
    parser = add_chromosome_imputation_argument()
    args = parser.parse_args()
    args.func(args)


if __name__=="__main__":
    main()
