"""
    Module to filter SNPs on imputation quality
    and format output for JASS
"""


def filter_output(zscores, fout, R2_threshold = 0.6, minimum_ld = 5):
    """
    procedure that format output for JASS

    Args:
        zscores (pandas dataframe): imputed zscore
         (as outputed from imputation_launcher.chromosome_imputation)
        fout (filename): filename where to save the formatted and filtered output
        R2_threshold (float): R square threshold bellow which SNPs are filtered from the output
    """


    zscores.reset_index(inplace = True)
    chr_fo = zscores[['index', 'pos', 'A0', 'A1', 'Z', 'Var', "ld_score"]]
    chr_fo["imputation_R2"] = 1-chr_fo["Var"]
    chr_fo.columns = ['rsID','pos','A0','A1','Z', 'Var', "ld_score", "imputation_R2"]
    print(chr_fo.shape)
    print(chr_fo.loc[(chr_fo.imputation_R2 > R2_threshold) & (chr_fo.ld_score > float(minimum_ld))].shape)
    chr_fo.loc[(chr_fo.imputation_R2 > R2_threshold) & (chr_fo.ld_score > float(minimum_ld))].to_csv(fout, sep="\t", index=False)
